"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContentForCompletionProvider = void 0;
const liquid_html_parser_1 = require("@shopify/liquid-html-parser");
const vscode_languageserver_1 = require("vscode-languageserver");
class ContentForCompletionProvider {
    constructor() { }
    async completions(params) {
        if (!params.completionContext)
            return [];
        const { node, ancestors } = params.completionContext;
        const parentNode = ancestors.at(-1);
        if (!node ||
            !parentNode ||
            node.type !== liquid_html_parser_1.NodeTypes.String ||
            parentNode.type !== liquid_html_parser_1.NodeTypes.ContentForMarkup) {
            return [];
        }
        const options = {
            block: 'Renders a static theme block within `sections` or `theme blocks`.\n',
            blocks: `Renders block elements within sections or other blocks as configured in the JSON template or section groups. 
See [theme blocks](https://shopify.dev/docs/storefronts/themes/architecture/blocks/theme-blocks) 
to see how to create theme blocks that can be used this way.\n`,
        };
        const partial = node.value;
        return Object.entries(options)
            .filter(([keyword, _description]) => keyword.startsWith(partial))
            .map(([keyword, description]) => ({
            label: keyword,
            kind: vscode_languageserver_1.CompletionItemKind.Keyword,
            documentation: {
                kind: 'markdown',
                value: description,
            },
        }));
    }
}
exports.ContentForCompletionProvider = ContentForCompletionProvider;
//# sourceMappingURL=ContentForCompletionProvider.js.map