"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RenameHandler = void 0;
const theme_check_common_1 = require("@shopify/theme-check-common");
const AssetRenameHandler_1 = require("./handlers/AssetRenameHandler");
const SnippetRenameHandler_1 = require("./handlers/SnippetRenameHandler");
/**
 * The RenameHandler is responsible for handling workspace/didRenameFiles notifications.
 *
 * Stuff we'll handle:
 * - When a snippet is renamed, then we'll change all the render calls
 * - When an asset is renamed, then we'll change the asset_url calls
 * - etc.
 */
class RenameHandler {
    constructor(connection, capabilities, documentManager, fileExists) {
        this.documentManager = documentManager;
        this.fileExists = fileExists;
        this.handlers = [
            new SnippetRenameHandler_1.SnippetRenameHandler(connection, capabilities),
            new AssetRenameHandler_1.AssetRenameHandler(connection, capabilities),
        ];
    }
    async onDidRenameFiles(params) {
        const rootUri = await (0, theme_check_common_1.findRoot)(theme_check_common_1.path.dirname(params.files[0].oldUri), this.fileExists);
        await this.documentManager.preload(rootUri);
        const theme = this.documentManager.theme(rootUri, true);
        const promises = this.handlers.map((handler) => handler.onDidRenameFiles(params, theme));
        await Promise.all(promises);
    }
}
exports.RenameHandler = RenameHandler;
//# sourceMappingURL=RenameHandler.js.map